.. SPDX-FileCopyrightText: 2023 Anna <cyber@sysrq.in>
.. SPDX-License-Identifier: WTFPL
.. No warranty.

Release Notes
=============

0.3.1
-----

* Replace NIH metadta parser with Portage API-based parser
* Replace use of os.getlogin with a more reliable implementation
* Support setting EPREFIX via cli
